@@ -17,6 +17,7 @@ import re
 
 from neutron.agent.linux import external_process
 from neutron.agent.linux import ip_lib
+from neutron.agent.linux import iptables_manager
 from neutron.common import utils
 from neutron_lib import constants as n_const
 from oslo_concurrency import lockutils
@@ -224,7 +225,8 @@ class MetadataAgent(object):
         self._load_config()
 
         # Launch the server that will act as a proxy between the VM's and Nova.
-        proxy = metadata_server.UnixDomainMetadataProxy(self.conf)
+        proxy = metadata_server.UnixDomainMetadataProxy(self.conf,
+                self.chassis)
         proxy.run()
 
         tables = ('Encap', 'Port_Binding', 'Datapath_Binding', 'SB_Global',
@@ -374,6 +376,24 @@ class MetadataAgent(object):
         else:
             self.teardown_datapath(datapath)
 
+    def _ensure_datapath_checksum(self, namespace):
+        """Ensure the correct checksum in the metadata packets in DPDK bridges
+
+        (LP#1904871) In DPDK deployments (integration bridge datapath_type ==
+        "netdev"), the checksum between the metadata namespace and OVS is not
+        correctly populated.
+        """
+        if (self.ovs_idl.db_get(
+                'Bridge', self.ovn_bridge, 'datapath_type').execute() !=
+                ovn_const.CHASSIS_DATAPATH_NETDEV):
+            return
+
+        iptables_mgr = iptables_manager.IptablesManager(
+            use_ipv6=True, nat=False, namespace=namespace)
+        rule = '-p tcp -m tcp -j CHECKSUM --checksum-fill'
+        iptables_mgr.ipv4['mangle'].add_rule('POSTROUTING', rule, wrap=False)
+        iptables_mgr.apply()
+
     def provision_datapath(self, datapath):
         """Provision the datapath so that it can serve metadata.
 
@@ -481,6 +501,9 @@ class MetadataAgent(object):
             'Interface', veth_name[0],
             ('external_ids', {'iface-id': port.logical_port})).execute()
 
+        # Ensure the correct checksum in the metadata traffic.
+        self._ensure_datapath_checksum(namespace)
+
         # Spawn metadata proxy if it's not already running.
         metadata_driver.MetadataDriver.spawn_monitored_metadata_proxy(
             self._process_monitor, namespace, METADATA_PORT,
