@@ -25,7 +25,6 @@ from ovs.stream import Stream
 from ovsdbapp.backend.ovs_idl import connection
 from ovsdbapp.backend.ovs_idl import event as row_event
 from ovsdbapp.backend.ovs_idl import idlutils
-from ovsdbapp import event
 
 from networking_ovn.common import config as ovn_config
 from networking_ovn.common import constants as ovn_const
@@ -33,6 +32,7 @@ from networking_ovn.common import exceptions
 from networking_ovn.common import hash_ring_manager
 from networking_ovn.common import utils
 from networking_ovn.db import hash_ring as db_hash_ring
+from networking_ovn.ovsdb import backports
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
@@ -351,7 +351,7 @@ class FIPAddDeleteEvent(row_event.RowEvent):
         self.driver.delete_mac_binding_entries(row.external_ip)
 
 
-class OvnDbNotifyHandler(event.RowEventHandler):
+class OvnDbNotifyHandler(backports.RowEventHandler):
     def __init__(self, driver):
         super(OvnDbNotifyHandler, self).__init__()
         self.driver = driver
@@ -368,7 +368,7 @@ class Ml2OvnIdlBase(connection.OvsdbIdl):
 class BaseOvnIdl(Ml2OvnIdlBase):
 
     def __init__(self, remote, schema):
-        self.notify_handler = event.RowEventHandler()
+        self.notify_handler = backports.RowEventHandler()
         super(BaseOvnIdl, self).__init__(remote, schema)
 
     @classmethod
@@ -530,6 +530,8 @@ class OvnSbIdl(OvnIdlDistributedLock):
         helper = idlutils.get_schema_helper(connection_string, schema_name)
         if 'Chassis_Private' in helper.schema_json['tables']:
             helper.register_table('Chassis_Private')
+        if 'FDB' in helper.schema_json['tables']:
+            helper.register_table('FDB')
         helper.register_table('Chassis')
         helper.register_table('Encap')
         helper.register_table('Port_Binding')
