@@ -28,6 +28,7 @@ from neutron_lib.callbacks import resources
 from neutron_lib import constants
 from neutron_lib import exceptions as n_exc
 from neutron_lib.exceptions import availability_zone as az_exc
+from neutron_lib.exceptions import l3 as l3_exc
 from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
 from oslo_config import cfg
@@ -356,6 +357,23 @@ class OVNL3RouterPlugin(test_mech_driver.OVNMechanismDriverTestCase):
                 ovn_const.OVN_NETWORK_NAME_EXT_ID_KEY:
                 utils.ovn_name(self.fake_network['id'])})
 
+    @mock.patch('neutron.db.l3_db.L3_NAT_dbonly_mixin.get_router')
+    @mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.get_port')
+    def test_remove_router_interface_router_not_found(self, get_port,
+                                                      get_router):
+        router_id = 'router-id'
+        interface_info = {'port_id': 'router-port-id'}
+        get_port.side_effect = n_exc.PortNotFound(port_id='router-port-id')
+        get_router.side_effect = l3_exc.RouterNotFound(
+            router_id='router-id')
+        self.l3_inst.remove_router_interface(
+            self.context, router_id, interface_info)
+        get_router.assert_called_once_with(mock.ANY, 'router-id')
+        self.l3_inst._ovn.lrp_del.assert_called_once_with(
+            'lrp-router-port-id', 'neutron-router-id', if_exists=True)
+        self.del_rev_p.assert_called_once_with(
+            'router-port-id', ovn_const.TYPE_ROUTER_PORTS)
+
     @mock.patch('neutron.db.extraroute_db.ExtraRoute_dbonly_mixin.'
                 'update_router')
     @mock.patch('neutron.db.l3_db.L3_NAT_dbonly_mixin.get_router')
